==> PopGenome_2.0.9.tar.gz: PopGenome/man/introgression.stats.Rd <==
\name{introgression.stats-methods}

\docType{methods}

\alias{introgression.stats,GENOME-method}
\alias{introgression.stats-methods}


\title{Introgression statistics}

\description{
 A generic function to estimate archaic admixture.
}

\usage{

\S4method{introgression.stats}{GENOME}(object,subsites=FALSE,do.D=TRUE)

}

 \arguments{

  \item{object}{An object of class \code{"GENOME"}}
  \item{subsites}{ 

                  \code{"transitions"}: SNPs that are transitions. \cr
                  \code{"transversions"}: SNPs that are transversions. \cr
                  \code{"syn"}: synonymous sites. \cr
                  \code{"nonsyn"}:  nonsynonymous sites. \cr
                  \code{"exon"}: SNPs in exon regions. \cr
                  \code{"intron"}: SNPs in intron regions. \cr
                  \code{"coding"}: SNPs in coding regions (CDS). \cr
                  \code{"utr"}:  SNPs in UTR regions. \cr
                  \code{"gene"}: SNPs in genes. \cr
		  \code{"intergenic"} : SNPs in intergenic regions. \cr
  } 

  \item{do.D}{Pattersons D statistic}

}


\value{

Returned value is a modified object of class \code{"GENOME"} \cr  \cr
--------------------------------------------------------- \cr
The following slots will be modified in the \code{"GENOME"}  object \cr
--------------------------------------------------------- \cr

\tabular{rlll}{

            \tab Slot                	    \tab Reference   \tab Description \cr

          1.\tab \code{D}	            \tab [1;eq. 2]   \tab Pattersons D statistic \cr
	  2.\tab \code{f}	            \tab [2]   \tab f statistic \cr

          }

}

\details{
To perform the D and f statistic one needs to define 3 populations via the function \code{set.populations}, \cr
where the third population represent the archaic population. In addition, an outgroup is required and have to be
set via the function \code{set.outgroup}. Here, only SNPs where the outgroup is monomorphic are considered.
f is the fraction of the genome that is admixed [2].
}

\references{
[1] Durand, E. Y., Patterson, N. J., Reich, D., & Slatkin, M. (2011). \emph{Testing for ancient admixture between closely related populations.} \cr Molecular Biology and Evolution, 28(8), 2239--2252. doi:10.1093/molbev/msr048 \cr
[2] Simon H Martin, Kanchon K Dasmahapatra, Nicola J Nadeau, et al. (2013). \emph{Genome-wide evidence for speciation with gene flow in Heliconius butterflies.} \cr Genome Res. doi:10.1101/gr.159426.113
}

\examples{
# GENOME.class <- readData("\home\Alignments")
# GENOME.class <- set.populations(GENOME.class,list(1:3,4:8,9:12))
# GENOME.class <- set.outgroup(GENOME.class,13)
# GENOME.class <- introgression.stats(GENOME.class)
# show the result:
# GENOME.class@D

}


\keyword{methods}

==> PopGenome_2.2.3.tar.gz: PopGenome/man/introgression.stats.Rd <==
\name{introgression.stats-methods}

\docType{methods}

\alias{introgression.stats,GENOME-method}
\alias{introgression.stats-methods}


\title{Introgression statistics}

\description{
 A generic function to estimate archaic admixture.
}

\usage{

\S4method{introgression.stats}{GENOME}(object,
subsites=FALSE,
do.D=FALSE,
do.BD=FALSE,
do.BDF=FALSE,
keep.site.info=TRUE,
block.size=FALSE,
dxy.table=FALSE,
D.global=FALSE,
do.CLR=FALSE,
dgt=2,
do.RNDmin=FALSE,
lambda=1)

}

 \arguments{

  \item{object}{An object of class \code{"GENOME"}}
  \item{subsites}{ 

                  \code{"transitions"}: SNPs that are transitions. \cr
                  \code{"transversions"}: SNPs that are transversions. \cr
                  \code{"syn"}: synonymous sites. \cr
                  \code{"nonsyn"}:  nonsynonymous sites. \cr
                  \code{"exon"}: SNPs in exon regions. \cr
                  \code{"intron"}: SNPs in intron regions. \cr
                  \code{"coding"}: SNPs in coding regions (CDS). \cr
                  \code{"utr"}:  SNPs in UTR regions. \cr
                  \code{"gene"}: SNPs in genes. \cr
		  \code{"intergenic"} : SNPs in intergenic regions. \cr
  } 

  \item{do.D}{Pattersons D and Martin's f statistic}
  \item{do.BD}{...}
  \item{do.BDF}{Bd-fraction}
  \item{keep.site.info}{Keep site specific values}
  \item{block.size}{jacknife}
  \item{dxy.table}{... not used ...}
  \item{D.global}{The global set of D,Bd values}
  \item{do.CLR}{Composite Likelihood approach}
  \item{dgt}{Digit for the CLR test}
  \item{do.RNDmin}{RNDmin (Rosenzweig, 2016)}
  \item{lambda}{Scale ... not used ...}

}


\value{

Returned value is a modified object of class \code{"GENOME"} \cr  \cr
--------------------------------------------------------- \cr
The following slots will be modified in the \code{"GENOME"}  object \cr
--------------------------------------------------------- \cr

\tabular{rlll}{

            \tab Slot                	    \tab Reference   \tab Description \cr

          1.\tab \code{D}	            \tab [1;eq. 2]   \tab Pattersons D statistic \cr
	  2.\tab \code{f}	            \tab [2]   \tab f statistic \cr

 3.\tab \code{BDF}	            \tab [x]   \tab Bd-fraction \cr
 4.\tab \code{RNDmin}	            \tab [x]   \tab RNDmin \cr
 
          }

}

\details{
To perform the D and f statistic one needs to define 3 populations via the function \code{set.populations}, \cr
where the third population represent the archaic population. In addition, an outgroup is required and have to be
set via the function \code{set.outgroup}. Here, only SNPs where the outgroup is monomorphic are considered.
f is the fraction of the genome that is admixed [2].
}

\references{
[1] Durand, E. Y., Patterson, N. J., Reich, D., & Slatkin, M. (2011). \emph{Testing for ancient admixture between closely related populations.} \cr Molecular Biology and Evolution, 28(8), 2239--2252. doi:10.1093/molbev/msr048 \cr
[2] Simon H Martin, Kanchon K Dasmahapatra, Nicola J Nadeau, et al. (2013). \emph{Genome-wide evidence for speciation with gene flow in Heliconius butterflies.} \cr Genome Res. doi:10.1101/gr.159426.113
}

\examples{
# GENOME.class <- readData("\home\Alignments")
# GENOME.class <- set.populations(GENOME.class,list(1:3,4:8,9:12))
# GENOME.class <- set.outgroup(GENOME.class,13)
# GENOME.class <- introgression.stats(GENOME.class, do.D=TRUE)
# GENOME.class <- introgression.stats(GENOME.class, do.BDF=TRUE)
# show the result:
# GENOME.class@D
# GENOME.class@f
# GENOME.class@BDF

}


\keyword{methods}
